icsemantic.catalog.tests.base.OntoCatalogTestCase

Package platecom :: Package ontocatalog :: Package tests :: Module base :: Class OntoCatalogTestCase |
[hide private]
[frames] | no frames]

# Class OntoCatalogTestCase

source code

    Products.PloneTestCase.PloneTestCase.PloneTestCase --+
                                                         |
                                                        OntoCatalogTestCase

We use this base class for all the tests in this package. If necessary, we can put common utility or setup code in here. This applies to unit test cases.

Instance Methods | [hide private]
setUp(self) | source code